# Copyright (C) 2013-2017, 2021 Vincent Forest (vaplv@free.fr)
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

cmake_minimum_required(VERSION 3.1)
include(SelectLibraryConfigurations)

# Try to find the Star2D devel. Once done this will define:
#   - Star2D_FOUND: system has Star2D
#   - Star2D_INCLUDE_DIR: the include directory
#   - Star2D: Link this to use s2d

# Look for library header
find_path(Star2D_INCLUDE_DIR star/s2d_version.h)

# Look for Release, Debug, RelWithDebInfo and MinSizeRel libraries
unset(Star2D_LIBRARY CACHE)
unset(Star2D_LIBRARY_RELEASE CACHE)
unset(Star2D_LIBRARY_DEBUG CACHE)
unset(Star2D_LIBRARY_RELWITHDEBINFO CACHE)
unset(Star2D_LIBRARY_MINSIZEREL CACHE)

# Find per configuration type libraries
find_library(Star2D_LIBRARY_RELEASE
  s2d
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library s2d used during release builds.")
find_library(Star2D_LIBRARY_DEBUG
  s2d-dbg
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library s2d used during debug builds.")
find_library(Star2D_LIBRARY_RELWITHDEBINFO
  s2d-rdbg
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library s2d used during release with debug info builds.")
find_library(Star2D_LIBRARY_MINSIZEREL
  s2d-mszr
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library s2d used during minsize builds.")

# Define the generic s2d library
if(Star2D_LIBRARY_RELEASE)
  set(Star2D_LIBRARY ${Star2D_LIBRARY_RELEASE})
elseif(Star2D_LIBRARY_RELWITHDEBINFO)
  set(Star2D_LIBRARY ${Star2D_LIBRARY_RELWITHDEBINFO})
elseif(Star2D_LIBRARY_MINSIZEREL)
  set(Star2D_LIBRARY ${Star2D_LIBRARY_MINSIZEREL})
elseif(Star2D_LIBRARY_DEBUG)
  set(Star2D_LIBRARY ${Star2D_LIBRARY_DEBUG})
endif()

# Define the per configuration library fallback when not found
set(_configs RELEASE DEBUG RELWITHDEBINFO MINSIZEREL)
foreach(_cfg ${_configs})
  if(NOT Star2D_LIBRARY_${_cfg})
    get_property(_doc CACHE Star2D_LIBRARY_${_cfg} PROPERTY HELPSTRING)
    set(Star2D_LIBRARY_${_cfg} 
      ${Star2D_LIBRARY} CACHE PATH ${_doc} FORCE)
  endif()
endforeach()

# Create the imported library target
add_library(Star2D SHARED IMPORTED)

# Setup the properties of the imported target
if(CMAKE_HOST_WIN32)
  set(_import_prop IMPORTED_IMPLIB)
else()
  set(_import_prop IMPORTED_LOCATION)
endif()
set_target_properties(Star2D PROPERTIES
  ${_import_prop} ${Star2D_LIBRARY}
  ${_import_prop}_RELEASE ${Star2D_LIBRARY_RELEASE}
  ${_import_prop}_DEBUG ${Star2D_LIBRARY_DEBUG}
  ${_import_prop}_RELWITHDEBINFO ${Star2D_LIBRARY_RELWITHDEBINFO}
  ${_import_prop}_MINSIZEREL ${Star2D_LIBRARY_MINSIZEREL}
  INTERFACE_INCLUDE_DIRECTORIES ${Star2D_INCLUDE_DIR})

# Check the package
include(FindPackageHandleStandardArgs)
FIND_PACKAGE_HANDLE_STANDARD_ARGS(Star2D DEFAULT_MSG
  Star2D_INCLUDE_DIR
  Star2D_LIBRARY)

