# Copyright (C) 2013-2017, 2021 Vincent Forest (vaplv@free.fr)
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

cmake_minimum_required(VERSION 3.1)
include(SelectLibraryConfigurations)

# Try to find the StarCMap devel. Once done this will define:
#   - StarCMap_FOUND: system has StarCMap
#   - StarCMap_INCLUDE_DIR: the include directory
#   - StarCMap: Link this to use scmap

# Look for library header
find_path(StarCMap_INCLUDE_DIR star/scmap_version.h)

# Look for Release, Debug, RelWithDebInfo and MinSizeRel libraries
unset(StarCMap_LIBRARY CACHE)
unset(StarCMap_LIBRARY_RELEASE CACHE)
unset(StarCMap_LIBRARY_DEBUG CACHE)
unset(StarCMap_LIBRARY_RELWITHDEBINFO CACHE)
unset(StarCMap_LIBRARY_MINSIZEREL CACHE)

# Find per configuration type libraries
find_library(StarCMap_LIBRARY_RELEASE
  scmap
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library scmap used during release builds.")
find_library(StarCMap_LIBRARY_DEBUG
  scmap-dbg
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library scmap used during debug builds.")
find_library(StarCMap_LIBRARY_RELWITHDEBINFO
  scmap-rdbg
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library scmap used during release with debug info builds.")
find_library(StarCMap_LIBRARY_MINSIZEREL
  scmap-mszr
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library scmap used during minsize builds.")

# Define the generic scmap library
if(StarCMap_LIBRARY_RELEASE)
  set(StarCMap_LIBRARY ${StarCMap_LIBRARY_RELEASE})
elseif(StarCMap_LIBRARY_RELWITHDEBINFO)
  set(StarCMap_LIBRARY ${StarCMap_LIBRARY_RELWITHDEBINFO})
elseif(StarCMap_LIBRARY_MINSIZEREL)
  set(StarCMap_LIBRARY ${StarCMap_LIBRARY_MINSIZEREL})
elseif(StarCMap_LIBRARY_DEBUG)
  set(StarCMap_LIBRARY ${StarCMap_LIBRARY_DEBUG})
endif()

# Define the per configuration library fallback when not found
set(_configs RELEASE DEBUG RELWITHDEBINFO MINSIZEREL)
foreach(_cfg ${_configs})
  if(NOT StarCMap_LIBRARY_${_cfg})
    get_property(_doc CACHE StarCMap_LIBRARY_${_cfg} PROPERTY HELPSTRING)
    set(StarCMap_LIBRARY_${_cfg} 
      ${StarCMap_LIBRARY} CACHE PATH ${_doc} FORCE)
  endif()
endforeach()

# Create the imported library target
add_library(StarCMap SHARED IMPORTED)

# Setup the properties of the imported target
if(CMAKE_HOST_WIN32)
  set(_import_prop IMPORTED_IMPLIB)
else()
  set(_import_prop IMPORTED_LOCATION)
endif()
set_target_properties(StarCMap PROPERTIES
  ${_import_prop} ${StarCMap_LIBRARY}
  ${_import_prop}_RELEASE ${StarCMap_LIBRARY_RELEASE}
  ${_import_prop}_DEBUG ${StarCMap_LIBRARY_DEBUG}
  ${_import_prop}_RELWITHDEBINFO ${StarCMap_LIBRARY_RELWITHDEBINFO}
  ${_import_prop}_MINSIZEREL ${StarCMap_LIBRARY_MINSIZEREL}
  INTERFACE_INCLUDE_DIRECTORIES ${StarCMap_INCLUDE_DIR})

# Check the package
include(FindPackageHandleStandardArgs)
FIND_PACKAGE_HANDLE_STANDARD_ARGS(StarCMap DEFAULT_MSG
  StarCMap_INCLUDE_DIR
  StarCMap_LIBRARY)

