# Copyright (C) 2013-2017, 2021 Vincent Forest (vaplv@free.fr)
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

cmake_minimum_required(VERSION 3.1)
include(SelectLibraryConfigurations)

# Try to find the StarEnc2D devel. Once done this will define:
#   - StarEnc2D_FOUND: system has StarEnc2D
#   - StarEnc2D_INCLUDE_DIR: the include directory
#   - StarEnc2D: Link this to use senc2d

# Look for library header
find_path(StarEnc2D_INCLUDE_DIR star/senc2d_version.h)

# Look for Release, Debug, RelWithDebInfo and MinSizeRel libraries
unset(StarEnc2D_LIBRARY CACHE)
unset(StarEnc2D_LIBRARY_RELEASE CACHE)
unset(StarEnc2D_LIBRARY_DEBUG CACHE)
unset(StarEnc2D_LIBRARY_RELWITHDEBINFO CACHE)
unset(StarEnc2D_LIBRARY_MINSIZEREL CACHE)

# Find per configuration type libraries
find_library(StarEnc2D_LIBRARY_RELEASE
  senc2d
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library senc2d used during release builds.")
find_library(StarEnc2D_LIBRARY_DEBUG
  senc2d-dbg
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library senc2d used during debug builds.")
find_library(StarEnc2D_LIBRARY_RELWITHDEBINFO
  senc2d-rdbg
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library senc2d used during release with debug info builds.")
find_library(StarEnc2D_LIBRARY_MINSIZEREL
  senc2d-mszr
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library senc2d used during minsize builds.")

# Define the generic senc2d library
if(StarEnc2D_LIBRARY_RELEASE)
  set(StarEnc2D_LIBRARY ${StarEnc2D_LIBRARY_RELEASE})
elseif(StarEnc2D_LIBRARY_RELWITHDEBINFO)
  set(StarEnc2D_LIBRARY ${StarEnc2D_LIBRARY_RELWITHDEBINFO})
elseif(StarEnc2D_LIBRARY_MINSIZEREL)
  set(StarEnc2D_LIBRARY ${StarEnc2D_LIBRARY_MINSIZEREL})
elseif(StarEnc2D_LIBRARY_DEBUG)
  set(StarEnc2D_LIBRARY ${StarEnc2D_LIBRARY_DEBUG})
endif()

# Define the per configuration library fallback when not found
set(_configs RELEASE DEBUG RELWITHDEBINFO MINSIZEREL)
foreach(_cfg ${_configs})
  if(NOT StarEnc2D_LIBRARY_${_cfg})
    get_property(_doc CACHE StarEnc2D_LIBRARY_${_cfg} PROPERTY HELPSTRING)
    set(StarEnc2D_LIBRARY_${_cfg} 
      ${StarEnc2D_LIBRARY} CACHE PATH ${_doc} FORCE)
  endif()
endforeach()

# Create the imported library target
add_library(StarEnc2D SHARED IMPORTED)

# Setup the properties of the imported target
if(CMAKE_HOST_WIN32)
  set(_import_prop IMPORTED_IMPLIB)
else()
  set(_import_prop IMPORTED_LOCATION)
endif()
set_target_properties(StarEnc2D PROPERTIES
  ${_import_prop} ${StarEnc2D_LIBRARY}
  ${_import_prop}_RELEASE ${StarEnc2D_LIBRARY_RELEASE}
  ${_import_prop}_DEBUG ${StarEnc2D_LIBRARY_DEBUG}
  ${_import_prop}_RELWITHDEBINFO ${StarEnc2D_LIBRARY_RELWITHDEBINFO}
  ${_import_prop}_MINSIZEREL ${StarEnc2D_LIBRARY_MINSIZEREL}
  INTERFACE_INCLUDE_DIRECTORIES ${StarEnc2D_INCLUDE_DIR})

# Check the package
include(FindPackageHandleStandardArgs)
FIND_PACKAGE_HANDLE_STANDARD_ARGS(StarEnc2D DEFAULT_MSG
  StarEnc2D_INCLUDE_DIR
  StarEnc2D_LIBRARY)

