# Copyright (C) 2013-2017, 2021 Vincent Forest (vaplv@free.fr)
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

cmake_minimum_required(VERSION 3.1)
include(SelectLibraryConfigurations)

# Try to find the StarEnc3D devel. Once done this will define:
#   - StarEnc3D_FOUND: system has StarEnc3D
#   - StarEnc3D_INCLUDE_DIR: the include directory
#   - StarEnc3D: Link this to use senc3d

# Look for library header
find_path(StarEnc3D_INCLUDE_DIR star/senc3d_version.h)

# Look for Release, Debug, RelWithDebInfo and MinSizeRel libraries
unset(StarEnc3D_LIBRARY CACHE)
unset(StarEnc3D_LIBRARY_RELEASE CACHE)
unset(StarEnc3D_LIBRARY_DEBUG CACHE)
unset(StarEnc3D_LIBRARY_RELWITHDEBINFO CACHE)
unset(StarEnc3D_LIBRARY_MINSIZEREL CACHE)

# Find per configuration type libraries
find_library(StarEnc3D_LIBRARY_RELEASE
  senc3d
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library senc3d used during release builds.")
find_library(StarEnc3D_LIBRARY_DEBUG
  senc3d-dbg
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library senc3d used during debug builds.")
find_library(StarEnc3D_LIBRARY_RELWITHDEBINFO
  senc3d-rdbg
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library senc3d used during release with debug info builds.")
find_library(StarEnc3D_LIBRARY_MINSIZEREL
  senc3d-mszr
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library senc3d used during minsize builds.")

# Define the generic senc3d library
if(StarEnc3D_LIBRARY_RELEASE)
  set(StarEnc3D_LIBRARY ${StarEnc3D_LIBRARY_RELEASE})
elseif(StarEnc3D_LIBRARY_RELWITHDEBINFO)
  set(StarEnc3D_LIBRARY ${StarEnc3D_LIBRARY_RELWITHDEBINFO})
elseif(StarEnc3D_LIBRARY_MINSIZEREL)
  set(StarEnc3D_LIBRARY ${StarEnc3D_LIBRARY_MINSIZEREL})
elseif(StarEnc3D_LIBRARY_DEBUG)
  set(StarEnc3D_LIBRARY ${StarEnc3D_LIBRARY_DEBUG})
endif()

# Define the per configuration library fallback when not found
set(_configs RELEASE DEBUG RELWITHDEBINFO MINSIZEREL)
foreach(_cfg ${_configs})
  if(NOT StarEnc3D_LIBRARY_${_cfg})
    get_property(_doc CACHE StarEnc3D_LIBRARY_${_cfg} PROPERTY HELPSTRING)
    set(StarEnc3D_LIBRARY_${_cfg} 
      ${StarEnc3D_LIBRARY} CACHE PATH ${_doc} FORCE)
  endif()
endforeach()

# Create the imported library target
add_library(StarEnc3D SHARED IMPORTED)

# Setup the properties of the imported target
if(CMAKE_HOST_WIN32)
  set(_import_prop IMPORTED_IMPLIB)
else()
  set(_import_prop IMPORTED_LOCATION)
endif()
set_target_properties(StarEnc3D PROPERTIES
  ${_import_prop} ${StarEnc3D_LIBRARY}
  ${_import_prop}_RELEASE ${StarEnc3D_LIBRARY_RELEASE}
  ${_import_prop}_DEBUG ${StarEnc3D_LIBRARY_DEBUG}
  ${_import_prop}_RELWITHDEBINFO ${StarEnc3D_LIBRARY_RELWITHDEBINFO}
  ${_import_prop}_MINSIZEREL ${StarEnc3D_LIBRARY_MINSIZEREL}
  INTERFACE_INCLUDE_DIRECTORIES ${StarEnc3D_INCLUDE_DIR})

# Check the package
include(FindPackageHandleStandardArgs)
FIND_PACKAGE_HANDLE_STANDARD_ARGS(StarEnc3D DEFAULT_MSG
  StarEnc3D_INCLUDE_DIR
  StarEnc3D_LIBRARY)

