# Copyright (C) 2013-2017, 2021 Vincent Forest (vaplv@free.fr)
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

cmake_minimum_required(VERSION 3.1)
include(SelectLibraryConfigurations)

# Try to find the StarSP devel. Once done this will define:
#   - StarSP_FOUND: system has StarSP
#   - StarSP_INCLUDE_DIR: the include directory
#   - StarSP: Link this to use ssp

# Look for library header
find_path(StarSP_INCLUDE_DIR star/ssp_version.h)

# Look for Release, Debug, RelWithDebInfo and MinSizeRel libraries
unset(StarSP_LIBRARY CACHE)
unset(StarSP_LIBRARY_RELEASE CACHE)
unset(StarSP_LIBRARY_DEBUG CACHE)
unset(StarSP_LIBRARY_RELWITHDEBINFO CACHE)
unset(StarSP_LIBRARY_MINSIZEREL CACHE)

# Find per configuration type libraries
find_library(StarSP_LIBRARY_RELEASE
  ssp
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library ssp used during release builds.")
find_library(StarSP_LIBRARY_DEBUG
  ssp-dbg
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library ssp used during debug builds.")
find_library(StarSP_LIBRARY_RELWITHDEBINFO
  ssp-rdbg
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library ssp used during release with debug info builds.")
find_library(StarSP_LIBRARY_MINSIZEREL
  ssp-mszr
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library ssp used during minsize builds.")

# Define the generic ssp library
if(StarSP_LIBRARY_RELEASE)
  set(StarSP_LIBRARY ${StarSP_LIBRARY_RELEASE})
elseif(StarSP_LIBRARY_RELWITHDEBINFO)
  set(StarSP_LIBRARY ${StarSP_LIBRARY_RELWITHDEBINFO})
elseif(StarSP_LIBRARY_MINSIZEREL)
  set(StarSP_LIBRARY ${StarSP_LIBRARY_MINSIZEREL})
elseif(StarSP_LIBRARY_DEBUG)
  set(StarSP_LIBRARY ${StarSP_LIBRARY_DEBUG})
endif()

# Define the per configuration library fallback when not found
set(_configs RELEASE DEBUG RELWITHDEBINFO MINSIZEREL)
foreach(_cfg ${_configs})
  if(NOT StarSP_LIBRARY_${_cfg})
    get_property(_doc CACHE StarSP_LIBRARY_${_cfg} PROPERTY HELPSTRING)
    set(StarSP_LIBRARY_${_cfg} 
      ${StarSP_LIBRARY} CACHE PATH ${_doc} FORCE)
  endif()
endforeach()

# Create the imported library target
add_library(StarSP SHARED IMPORTED)

# Setup the properties of the imported target
if(CMAKE_HOST_WIN32)
  set(_import_prop IMPORTED_IMPLIB)
else()
  set(_import_prop IMPORTED_LOCATION)
endif()
set_target_properties(StarSP PROPERTIES
  ${_import_prop} ${StarSP_LIBRARY}
  ${_import_prop}_RELEASE ${StarSP_LIBRARY_RELEASE}
  ${_import_prop}_DEBUG ${StarSP_LIBRARY_DEBUG}
  ${_import_prop}_RELWITHDEBINFO ${StarSP_LIBRARY_RELWITHDEBINFO}
  ${_import_prop}_MINSIZEREL ${StarSP_LIBRARY_MINSIZEREL}
  INTERFACE_INCLUDE_DIRECTORIES ${StarSP_INCLUDE_DIR})

# Check the package
include(FindPackageHandleStandardArgs)
FIND_PACKAGE_HANDLE_STANDARD_ARGS(StarSP DEFAULT_MSG
  StarSP_INCLUDE_DIR
  StarSP_LIBRARY)

